--[[
WarlockReminder Continued v1.43
29 Jun 2011
Author: CKlausi/Biny of Anetheron EU
Original Author of WarlockReminder: Vux of Dragonblight-US
Description: Helpful reminders for Warlocks
File: WarlockReminder.lua
]]--

WarlockReminder = LibStub("AceAddon-3.0"):NewAddon("WarlockReminder", "AceConsole-3.0", "AceEvent-3.0", "AceTimer-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("WarlockReminder")

-- Default Values
local defaults = {
    profile = {
		--Reminder
		showArmor = true,
		showSL = true,
		showFlask = true,
		showPet = true,
		showFood = true,
		-- Pets
		petAffliction = "succubus",
		petDemonology = "felguard",
		petDestruction = "imp",
		-- DS
		playDrainSoul = true,
		showDrainSoulMessage = true,
		drainSoulPercent = 25 / 100,
		drainSoulHealth = 100000,
		showDrainSoulFrame = true,
		drainSoulDuration = 5,
		-- Output
		outputFrame = "wlrframe",
		-- Anchor
		wlrAnchorTop = UIParent:GetHeight()/2, 
		wlrAnchorLeft = UIParent:GetWidth()/2,
		wlrAnchorAlpha = 1,
		wlrAnchorSize = 1,
		-- Decimation
		playDecimationSound = true,
		showDecimationMessage = true,
		showDecimationFrame = true,
		-- MoltenCore
		playMoltenCoreSound = false,
		showMoltenCoreMessage = false,
		showMoltenCoreFrame = false,
		-- Shadow Trance
		playShadowTranceSound = false,
		showShadowTranceMessage = false,
		showShadowTranceFrame = false,
		-- Empowered Imp
		playEmpoweredImpSound = false,
		showEmpoweredImpMessage = false,
		showEmpoweredImpFrame = false,
		-- Dark Intent
		showDarkIntentFrame = true,
		diFrameTop = (UIParent:GetHeight()/2) +40,
		diFrameLeft = (UIParent:GetWidth()/2),
		diFrameAlpha = 1,
		diBgAlpha = 0.5,
		diFrameSize = 1,
		diFrameLock = false,
		diFrameShowRealm = false,
		diExtraWidth = 0,
		diFontSize = 11,
		-- ISF
		showIsf = true,
		isfLock = false,
		isfInCombat = true,
		isfThreshold = 0,
		isfTop = (UIParent:GetHeight()/2) -40,
		isfLeft = (UIParent:GetWidth()/2),
		isfTextPosition = 0,
		isfFontSize = 10,
		isfAlpha = 1,
		isfWidth = 160,
		isfHeight = 20,
		-- Custom
		showCustom = true,
		soundCustom = true,
		wlrCustomAnchorTop = (UIParent:GetHeight()/2),
		wlrCustomAnchorLeft = (UIParent:GetWidth()/2),
		wlrCustomAnchorAlpha = 1,
		wlrCustomAnchorSize = 1,
		CustomSpells = {
			[1] = 89937,
			[2] = 70840,
		}
    },
}
-- END Default Values

-- Wlr Id table
wlrId = {
	-- Spell Ids
	Spell = {
		FelArmor = 28176,
		DemonArmor = 687,
		SoulLink = 19028,
		DrainSoul = 1120,
		UnendingBreath = 5697,
		SoulFire = 6353
	},
	Flask = {
		--Wotlk
		FlaskOfFrostwyrm = 53755,
		SpellpowerElixir = 33721,
		--Cata
		ElixirOfTheMaster = 79635,
		ElixirOfTheMightySpeed = 79632,
		ElixirOfImpossibleAccuracy = 79481,
		ElixirOfTheCobra = 79477,
		FlaskOfTheDraconicMind = 79470
	},
	Food = {
		WellFed = 57399 -- there are so many different buffs - using textures
	},
	-- Pets
	Pets = {
		imp = 688,
		voidwalker = 697,
		succubus = 712,
		felhunter = 691,
		felguard = 30146,
	},
	-- Procs
	Procs = {
		Decimation1 = 63165,
		Decimation2 = 63167,
		MoltenCore1 = 47383,
		MoltenCore2 = 71162,
		MoltenCore3 = 71165,
		ShadowTrance = 17941,
		EmpoweredImp = 54278,
		Isf = 85383
	},
	DarkIntent = {
		-- Dark Intent
		DarkIntentSpell = 80398,
		DarkIntent = 85767,
		DarkIntentTarget = ""
	},
	Custom = {
		-- Custom
		FelSpark = 89937
	},
	timeLeft = 0
}



-- Addon start
function WarlockReminder:OnInitialize()
	local _, englishClass = UnitClass("player")
	if ( englishClass == "WARLOCK") then
		self.db = LibStub("AceDB-3.0"):New("WarlockReminderDB", defaults, "Default")
	
		self:CreateFrames()
		self:DiFrameSetup()
		self:IsfSetup()
		
		self.db.RegisterCallback(self, "OnProfileChanged", "RefreshConfig")
		self.db.RegisterCallback(self, "OnProfileCopied", "RefreshConfig")
		self.db.RegisterCallback(self, "OnProfileReset", "RefreshConfig")
		self.db.RegisterCallback(self, "OnNewProfile", "NewConfig")
		
		self:SetUpOptions()
		
		--DarkIntentTimer = self:ScheduleRepeatingTimer("DarkIntentTracker", 2)
	end
end

function WarlockReminder:OnEnable()
	local _, englishClass = UnitClass("player")
	if ( englishClass == "WARLOCK") then
		DrainSoulPlayed = false
		DecimationPlayed = false
		ReminderPlayed = false
		self:RegisterEvent("PLAYER_TARGET_CHANGED")
		self:RegisterEvent("UNIT_COMBAT")
		self:RegisterEvent("UNIT_AURA")
		self:RegisterEvent("UNIT_PET")
		self:RegisterEvent("COMPANION_UPDATE")
		self:RegisterEvent("UNIT_SPELLCAST_SENT")
		self:RegisterEvent("PLAYER_REGEN_DISABLED")
		self:RegisterEvent("PLAYER_REGEN_ENABLED")
		
		-- Anchor Position
		if (not self.db.profile.wlrAnchorLeft and not self.db.profile.wlrAnchorTop) then
			wlranchor:Show()
			-- When no changes are made, set left and top of the anchor
			self:SetWlrAnchorLeft(self:GetLeft())
			self:SetWlrAnchorTop(self:GetTop())
		else
			wlranchor:ClearAllPoints()
			wlranchor:SetPoint("TOPLEFT",UIParent,"BOTTOMLEFT", self.db.profile.wlrAnchorLeft, self.db.profile.wlrAnchorTop)
			wlrframe:SetAlpha(self.db.profile.wlrAnchorAlpha)
			wlrframe:SetWidth(48*self.db.profile.wlrAnchorSize)
			wlrframe:SetHeight(48*self.db.profile.wlrAnchorSize)
		end
		
		-- CustomReminder Position
		if (not self.db.profile.wlrCustomAnchorLeft and not self.db.profile.wlrCustomAnchorTop) then
			wlrcustomanchor:Show()
			-- When no changes are made, set left and top of the anchor
			self:SetWlrCustomAnchorLeft(self:GetLeft())
			self:SetWlrCustomAnchorTop(self:GetTop())
		else
			self:CustomSetup()
		end
		
		-- DiFrame Position
		if (not self.db.profile.diFrameLeft and not self.db.profile.diFrameTop) then
			diFrame:Show()
			-- When no changes are made, set left and top of the frame
			self:SetDiFrameLeft(self:GetLeft())
			self:SetDiFrameTop(self:GetTop())
		else
			self:DiFrameSetup()
		end
		
		-- Isf Position
		if (not self.db.profile.isfLeft and not self.db.profile.isfTop) then
			isfBar:Show()
			-- When no changes are made, set left and top of the frame
			self:SetIsfLeft(isfBar:GetLeft())
			self:SetIsfTop(isfBar:GetTop())
		else
			self:IsfSetup()
		end
	end
end
-- END Addon start


local function round(number, decimals)
    return (("%%.%df"):format(decimals)):format(number)
end

-- Check if the unit has a buff, showcount = true returns how often the buff is up
function WarlockReminder:UnitHasBuff(unit, buff, showcount)
    for i=1, 40 do
		local name, rank, iconTexture, count = UnitBuff(unit, i)
        if ( name == GetSpellInfo(buff) ) then
			if(showcount == true) then return count
			else return true end
        end
    end
	return false
end

-- Check if the unit has my buff
local function UnitHasMyBuff(unit, buff)
	for i=1, 40 do
		local buffName, _, _, _, _, _, _, source, _ = UnitBuff(unit, i)
		if (source == "player" and
			source ~=  nil and
			buffName == GetSpellInfo(buff))
		then
			return true
		end
	end
	return false
end

-- Check if the unit has a buff using textures
local function UnitHasBuffByTexture(unit, buff)
	local  _, _, icon = GetSpellInfo(buff)
    for i=1, 40 do
		local _, _, iconTexture = UnitBuff(unit, i)
        if ( iconTexture == icon  ) then
			return true
        end
    end
	return false
end

-- Output Blizzard Message or Chat
function WarlockReminder:Output(input, red, green, blue, duration)
	-- Simulate default values, is there a better way to do this in lua?
	if red == nil then red = 0.0 end
	if green == nil then green = 1.0 end
	if blue == nil then blue = 0.0 end
	if duration == nil then duration = 5.0 end
	
	if self.db.profile.outputFrame == "chat" then
		self:Print(input)
	else
		UIErrorsFrame:AddMessage(input, red, green, blue, duration)
	end	
end
-- END Output

-- EVENTS
function WarlockReminder:UNIT_SPELLCAST_SENT(event, unit, spell, _, target)
	if(unit == "player" and spell == GetSpellInfo(wlrId["DarkIntent"]["DarkIntent"])) then
		wlrId["DarkIntent"]["DarkIntentTarget"] = target
	end
end

function WarlockReminder:PLAYER_TARGET_CHANGED()
	DrainSoulPlayed = false
	ReminderPlayed = false
	DrainSoulShown = false
	self:DrainSoulReminder()
	self:Reminder()
end

function WarlockReminder:PLAYER_REGEN_DISABLED()
	self:DrainSoulReminder()
	if self.db.profile.showIsf == true then isfBar:Show() end
end

function WarlockReminder:PLAYER_REGEN_ENABLED()
	self:ReminderPlayed()
	self:Reminder()
	if self.db.profile.isfInCombat == true then isfBar:Hide() end
end

function WarlockReminder:UNIT_COMBAT(unit)
	self:DrainSoulReminder()
end

function WarlockReminder:UNIT_AURA(event, unit)
	if unit == "player" then
		self:ReminderPlayed()
		self:MoltenCoreReminder()
		self:DecimationReminder()
		self:DrainSoulReminder()
		self:DrainSoulReminder()
		self:CustomReminder()
		self:Reminder()
	end
end

function WarlockReminder:UNIT_PET(event, unit)
	if unit == "player" then
		self:Reminder()
	end
end

function WarlockReminder:COMPANION_UPDATE(event, companion)
	if companion == "MOUNT" then
		self:Reminder()
	end
end
-- END EVENTS

function WarlockReminder:ReminderPlayed()

	if ( not self:UnitHasBuff("player", wlrId["Procs"]["ShadowTrance"]) 
	) then
		ShadowTrancePlayed = false
		if ( not DrainSoulPlayed and
			not DrainSoulShown 
		) then
			self:WlrFrame(false)
		end
	end
	if ( not self:UnitHasBuff("player", wlrId["Procs"]["EmpoweredImp"]) 
	) then
		EmpoweredImpPlayed = false
		if ( not DrainSoulPlayed and
			not DrainSoulShown 
		) then
			self:WlrFrame(false)
		end
	end
	if ( not self:UnitHasBuff("player", wlrId["Procs"]["Decimation1"]) and
		not self:UnitHasBuff("player", wlrId["Procs"]["Decimation2"]) 
	) then
		DecimationPlayed = false
	end
	if ( not self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore1"]) and
		not self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore2"]) and
		not self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore3"])
	) then
		MoltenCorePlayed = false
	end

end

-- Warlock reminder
function WarlockReminder:Reminder()
	
	missing = false
	
	-- Player not in vehicle and not dead
	if( not UnitInVehicle("player") and
		not UnitIsDead("player")
	) then
		if ( not DrainSoulShown and -- don't show when drain soul is up
			not DrainSoulPlayed and
			not DecimationPlayed and -- don't show when decimation is up
			not MoltenCorePlayed and -- don't show when molten core is up
			not ShadowTrancePlayed and -- don't show when shadow trance is up
			not EmpoweredImpPlayed -- don't show when shadow trance is up
		) then
			-- Bufffood
			if ( self.db.profile.showFood and
				UnitLevel("target") < 0 and
				UnitHealth("target") * 100 / UnitHealthMax("target") > 98 and
				not UnitHasBuffByTexture("player", wlrId["Food"]["WellFed"]) ) then
					missing = true
					if self.db.profile.outputFrame == "wlrframe" then
						self:WlrFrame(true, wlrId["Food"]["WellFed"])
					else
						self:Output("* ".. L["Missing Food"] .." *")
					end
			else
				if not missing then self:WlrFrame(false) end
			end
			
			-- Flask & Elixir
			if ( self.db.profile.showFlask and
				UnitLevel("target") < 0 and
				UnitHealth("target") * 100 / UnitHealthMax("target") > 98 and
				-- Wotlk
				not self:UnitHasBuff("player", wlrId["Flask"]["FlaskOfFrostwyrm"]) and
				not self:UnitHasBuff("player", wlrId["Flask"]["SpellpowerElixir"]) and
				-- Cata
				not self:UnitHasBuff("player", wlrId["Flask"]["ElixirOfTheMaster"]) and
				not self:UnitHasBuff("player", wlrId["Flask"]["ElixirOfTheMightySpeed"]) and
				not self:UnitHasBuff("player", wlrId["Flask"]["ElixirOfImpossibleAccuracy"]) and
				not self:UnitHasBuff("player", wlrId["Flask"]["ElixirOfTheCobra"]) and
				not self:UnitHasBuff("player", wlrId["Flask"]["FlaskOfTheDraconicMind"]) ) then
					missing = true
					if self.db.profile.outputFrame == "wlrframe" then
						self:WlrFrame(true, wlrId["Flask"]["FlaskOfTheDraconicMind"])
					else
						self:Output("* ".. L["Missing Flask"] .." *")
					end
			else
				if not missing then self:WlrFrame(false) end
			end
			
			-- Soul Link
			local slusable, slnomana = IsUsableSpell(wlrId["Spell"]["SoulLink"])
			if( self.db.profile.showSL and
				UnitExists("pet") and
				slusable == 1 and -- Spell already learned?
				not IsMounted("player") ) then
					if( not self:UnitHasBuff("player", wlrId["Spell"]["SoulLink"]) ) then
						missing = true
						if self.db.profile.outputFrame == "wlrframe" then
							self:WlrFrame(true, wlrId["Spell"]["SoulLink"])
						else
							self:Output("* ".. L["Missing SL"] .." *")
						end
					end
			else
				if not missing then self:WlrFrame(false) end
			end
			
			-- Pet
			if ( self.db.profile.showPet and
				not UnitExists("pet") and
				not IsMounted("player") ) then
					missing = true
					if self.db.profile.outputFrame == "wlrframe" then
						local pet = ""
						local talents = GetPrimaryTalentTree(false, false, GetActiveTalentGroup(false, false))
						if talents == 1 then pet = wlrId["Pets"][self.db.profile.petAffliction] -- Affli
						elseif (talents == 2) then pet = wlrId["Pets"][self.db.profile.petDemonology] -- Demo
						else pet = wlrId["Pets"][self.db.profile.petDestruction] end -- Destro + unknown
						self:WlrFrame(true, pet)
					else
						self:Output("* ".. L["Missing Pet"] .." *")
					end
			else
				if not missing then	self:WlrFrame(false) end
			end

			-- Armor
			local felarmorusable, felarmornomana = IsUsableSpell(wlrId["Spell"]["FelArmor"])
			local demonarmorusable, demonarmornomana = IsUsableSpell(wlrId["Spell"]["DemonArmor"])
			if ( self.db.profile.showArmor and
				-- Spell already learned?
				( felarmorusable == 1 or
				demonarmorusable == 1 ) and
				not self:UnitHasBuff("player", wlrId["Spell"]["FelArmor"]) and -- Fel Armor
				not self:UnitHasBuff("player", wlrId["Spell"]["DemonArmor"])  -- Demon Armor
			) then
				missing = true
				if self.db.profile.outputFrame == "wlrframe" then
					local usearmor = ""
					if felarmorusable == 1 then usearmor = wlrId["Spell"]["FelArmor"]
					else usearmor = wlrId["Spell"]["DemonArmor"] end
					self:WlrFrame(true, usearmor)
				else 
					self:Output("* ".. L["Missing Armor"] .." *")
				end
			else
				if not missing then self:WlrFrame(false) end
			end
		end
	else
		self:WlrFrame(false)
	end
end
-- END Warlock reminder

-- DrainSoul reminder
function WarlockReminder:DrainSoulReminder()
	local dsusable, dsnomana = IsUsableSpell(wlrId["Spell"]["DrainSoul"])
	if ( not UnitInVehicle("player") and
		not ShadowTrancePlayed and -- don't show when Shadow Trance is up
		-- dsusable == 1 and -- Spell already learned?
		UnitCanAttack("player", "target") and
		not UnitIsDead("target") and
		UnitHealth("target") > 0 and
		UnitHealth("target") * 100 / UnitHealthMax("target") <= self.db.profile.drainSoulPercent * 100 and
		UnitHealthMax("target") >= tonumber(self.db.profile.drainSoulHealth)
		) then
			-- play ds sound
			if ( self.db.profile.playDrainSoul and
				not DrainSoulPlayed
				) then
				PlaySoundFile("Interface\\AddOns\\WarlockReminder\\Sounds\\quaddamage.ogg")
			end
			-- show ds message
			if ( self.db.profile.showDrainSoulMessage and 
				not DrainSoulPlayed
				) then
				self:Output("* ".. L["Drain Soul!"] .." *", 1.0, 0.0, 0.0)
			end
			-- show ds wlrframe
			if self.drainsoultimer then local temptimer = self.drainsoultimer 
			else temptimer = nil end
			if ( self.db.profile.showDrainSoulFrame and
				not self:TimeLeft(temptimer) and
				not DrainSoulShown
			) then
				DrainSoulShown = true
				self:WlrDrainSoulFrame(true)
			end
			DrainSoulPlayed = true
	else 
		DrainSoulPlayed = false
		DrainSoulShown = false
	end
end
-- END DrainSoul reminder

-- Decimation reminder
function WarlockReminder:DecimationReminder()
	if( ( self:UnitHasBuff("player", wlrId["Procs"]["Decimation1"]) or
		self:UnitHasBuff("player", wlrId["Procs"]["Decimation2"]) )
	) then
		-- play decimation sound
		if ( self.db.profile.playDecimationSound and
			not DecimationPlayed
		) then
			PlaySoundFile("Interface\\AddOns\\WarlockReminder\\Sounds\\quaddamage.ogg")
		end
		-- show decimation message
		if ( self.db.profile.showDecimationMessage and 
			not DecimationPlayed
		) then
			self:Output("* ".. L["Decimation!"] .." *", 1.0, 0.0, 0.0)
		end
		-- show decimation frame
		if  self.db.profile.showDecimationFrame then
			self:WlrFrame(true, wlrId["Procs"]["Decimation2"])
		end
		DecimationPlayed = true
	else
		DecimationPlayed = false
	end
end
-- END Decimation reminder

-- moltencore reminder
function WarlockReminder:MoltenCoreReminder()
	if( ( self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore1"]) or
		self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore2"]) or
		self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore3"]) ) and
		not DecimationPlayed  -- don't show when decimation is up
	) then
		-- play moltencore sound
		if ( self.db.profile.playMoltenCoreSound and
			not MoltenCorePlayed
		) then
			PlaySoundFile("Sound\\Spells\\Clearcasting_Impact_Chest.wav")
		end
		-- show moltencore message
		if ( self.db.profile.showMoltenCoreMessage and 
			not MoltenCorePlayed
		) then
			self:Output("* ".. L["Molten Core!"] .." *", 1.0, 0.0, 0.0)
		end
		-- show moltencore frame
		if  self.db.profile.showMoltenCoreFrame then
			-- How often Molten Core is up
			local count = 0
			if self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore1"]) then count = self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore1"], true)
			elseif self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore2"]) then count = self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore2"], true)
			else count = self:UnitHasBuff("player", wlrId["Procs"]["MoltenCore3"], true) end
			
			self:WlrMoltenCoreFrame(true, count)
		end
		MoltenCorePlayed = true
	else
		MoltenCorePlayed = false
	end
end
-- END moltencore reminder

-- ShadowTrance reminder
function WarlockReminder:ShadowTranceReminder()
	if( self:UnitHasBuff("player", wlrId["Procs"]["ShadowTrance"])
	) then
		-- play shadowtrance sound
		if ( self.db.profile.playShadowTranceSound and
			not ShadowTrancePlayed
		) then
			PlaySoundFile("Sound\\Spells\\Clearcasting_Impact_Chest.wav")
		end
		-- show shadowtrance message
		if ( self.db.profile.showShadowTranceMessage and 
			not ShadowTrancePlayed
		) then
			self:Output("* ".. L["Shadow Trance!"] .." *", 1.0, 0.0, 0.0)
		end
		-- show shadowtrance frame
		if  self.db.profile.showShadowTranceFrame then
			self:WlrFrame(true, wlrId["Procs"]["ShadowTrance"])
		end
		ShadowTrancePlayed = true
	else
		ShadowTrancePlayed = false
	end
end
-- END ShadowTrance reminder

-- EmpoweredImp reminder
function WarlockReminder:EmpoweredImpReminder()
	if(  self:UnitHasBuff("player", wlrId["Procs"]["EmpoweredImp"])
	) then
		-- play empowered imp sound
		if ( self.db.profile.playEmpoweredImpSound and
			not EmpoweredImpPlayed
			) then
			PlaySoundFile("Sound\\Spells\\Clearcasting_Impact_Chest.wav")
		end
		-- show empowered imp message
		if ( self.db.profile.showEmpoweredImpMessage and 
			not EmpoweredImpPlayed
			) then
			self:Output("* ".. L["Empowered Imp!"] .." *", 1.0, 0.0, 0.0)
		end
		-- show empowered imp frame
		if  self.db.profile.showEmpoweredImpFrame then
			self:WlrFrame(true, wlrId["Procs"]["EmpoweredImp"])
		end
		EmpoweredImpPlayed = true
	else
		EmpoweredImpPlayed = false
	end
end
-- END EmpoweredImp reminder

-- Dark Intent Tracker
function WarlockReminder:DarkIntentTracker()
	local output = 0
	if(	(UnitInRaid(wlrId["DarkIntent"]["DarkIntentTarget"]) or UnitInParty(wlrId["DarkIntent"]["DarkIntentTarget"])) and
		UnitHasMyBuff(wlrId["DarkIntent"]["DarkIntentTarget"], wlrId["DarkIntent"]["DarkIntent"]) == true
	)then
		local _, englishClass = UnitClass(wlrId["DarkIntent"]["DarkIntentTarget"])
		local fontColor
		local diName
		
		if (not (wlrId["DarkIntent"]["DarkIntentTarget"] == "")) then
			local buffName, _, _, _, _, _, expirationTime, _, _ = UnitBuff(wlrId["DarkIntent"]["DarkIntentTarget"], GetSpellInfo(wlrId["DarkIntent"]["DarkIntent"]))
			timeLeft = expirationTime
		end
		
		if((-1*(GetTime()-timeLeft)) < 0) then output = ""
		elseif((-1*(GetTime()-timeLeft)) >= 60) then output = format("%.0f",ceil(-1*(GetTime()-timeLeft)/60)).." "..L["minutes"]
		else output = format("%.0f",-1*(GetTime()-timeLeft)).." "..L["seconds"] end
		
		if(self.db.profile.diFrameShowRealm == true) then
			diName = wlrId["DarkIntent"]["DarkIntentTarget"]
		else
			diName, diRealm = strsplit("-", wlrId["DarkIntent"]["DarkIntentTarget"])
		end
		
		if RAID_CLASS_COLORS[englishClass] then
			fontColor = RAID_CLASS_COLORS[englishClass]
			diFontFrame.text:SetTextColor(fontColor["r"], fontColor["g"], fontColor["b"])
		end
		diFontFrame.text:SetText(diName)
		diFontFrame.textTime:SetText(output)
		self:DiFrameSetFontGab()
	else
		timeLeft = 0
		diFontFrame.text:SetTextColor(1, 1, 1)
		diFontFrame.text:SetText(L["No Dark Intent"])
		diFontFrame.textTime:SetText("")
	end
end
-- END Dark Intent Tracker

-- Isfreminder
function WarlockReminder:IsfReminder()
	if self.db.profile.showIsf then
		local _, _, _, _, _, _, expirationTime = UnitBuff("player", GetSpellInfo(wlrId["Procs"]["Isf"]))
		local _, _, _, _, _, _, castTime = GetSpellInfo(wlrId["Spell"]["SoulFire"])

		if not (expirationTime == nil) then
			local isfLeft = (-1*(GetTime()-expirationTime))
			isfBar:SetValue(isfLeft)
			isfBar.text:SetText(round(isfLeft, 1) .. L["seconds"])
			if(tonumber(isfLeft) < ((castTime/1000)+self.db.profile.isfThreshold)) then isfBar:SetStatusBarColor(170/255, 10/255, 10/255)
			else isfBar:SetStatusBarColor(10/255, 170/255, 10/255) end
		else
			isfBar:SetValue(0)
			isfBar.text:SetText(L["No Improved Soul Fire"])
		end
	end
end
-- END Isfreminder

-- OnUpdate
function WarlockReminder:OnUpdate()
	self:DarkIntentTracker()
	self:IsfReminder()
end

