--[[
WarlockReminder Continued v1.43
29 Jun 2011
Author: CKlausi/Biny of Anetheron EU
Original Author of WarlockReminder: Vux of Dragonblight-US
Description: Helpful reminders for Warlocks
File: WarlockReminderConfig.lua
]]--

local WarlockReminder = LibStub("AceAddon-3.0"):GetAddon("WarlockReminder")
local L = LibStub("AceLocale-3.0"):GetLocale("WarlockReminder")

local AceConfigDialog = LibStub("AceConfigDialog-3.0")

-- Output frames
local OutputFrames = {
	["chat"] = L["Chat"],
	["blizzard"] = L["Blizzard Message Frame"],
	["wlrframe"] = L["WarlockReminder Frame"],
}
-- Text Positions
local TextPositions = {
	[0] = L["Right"],
	[1] = L["Left"],
	[2] = L["Center"],
}

local PetChoice = {
	["felhunter"] = L["Felhunter"],
	["succubus"] = L["Succubus"],
	["imp"] = L["Imp"],
	["voidwalker"] = L["Voidwalker"],
	["felguard"] = L["Felguard"],
}

local SlashOptions = {
  type = "group",
  handler = WarlockReminder,
  args = {
    config = {
      type = "execute",
	  name = L["Configure"],
      desc = L["Open the options dialog of WarlockReminder"],
      func = function()
		InterfaceOptionsFrame_OpenToCategory(WarlockReminder.optionFrames.profile)
        InterfaceOptionsFrame_OpenToCategory(WarlockReminder.optionFrames.main)
      end,
    },
  },
}

local SlashCmds = {
  "wlr",
  "warlockreminder",
}

-- Options
local wlroptions = {
    name = "WarlockReminder",
    handler = WarlockReminder,
    type = "group",
	childGroups = "tree",
    args = {
		reminder = {
            type = "group",
			order = 0,
            name = L["Reminders"],
            args = {
				armor = {
					type = "toggle",
					order = 10,
					name = L["Armor"],
					desc = L["Show armor reminder"],
					get = "GetShowArmor",
					set = "SetShowArmor",
				},
				sl = {
					type = "toggle",
					order = 20,
					name = L["Soul Link"],
					desc = L["Show Soul Link reminder"],
					get = "GetShowSL",
					set = "SetShowSL",
				},
				flask = {
					type = "toggle",
					order = 30,
					name = L["Flask and Elixir"],
					desc = L["Show Flask and Elixir reminder"],
					get = "GetShowFlask",
					set = "SetShowFlask",
				},
				food = {
					type = "toggle",
					order = 40,
					name = L["Well Fed"],
					desc = L["Show food reminder"],
					get = "GetShowFood",
					set = "SetShowFood",
				},
				pet = {
					type = "toggle",
					order = 50,
					name = L["Pet"],
					desc = L["Show pet reminder"],
					get = "GetShowPet",
					set = "SetShowPet",
					width = "full",
				},
				afflictionpet = {
					type = "select",
					name = L["Affliction"],
					desc = L["Pet for Affliction"],
					order = 60,
					values = PetChoice,
					disabled = function(self) return not WarlockReminder:GetShowPet("Pet") end,
					get = "GetPetAffliction",
					set = "SetPetAffliction",
				},
				demonpet = {
					type = "select",
					name = L["Demonology"],
					desc = L["Pet for Demonology"],
					order = 70,
					values = PetChoice,
					disabled = function(self) return not WarlockReminder:GetShowPet("Pet") end,
					get = "GetPetDemonology",
					set = "SetPetDemonology",
				},
				destrupet = {
					type = "select",
					name = L["Destruction"],
					desc = L["Pet for Destruction"],
					order = 80,
					values = PetChoice,
					disabled = function(self) return not WarlockReminder:GetShowPet("Pet") end,
					get = "GetPetDestruction",
					set = "SetPetDestruction",
				},
			},
		},
		combatreminder = {
            type = "group",
			order = 2,
            name = L["Combat Reminder"],
            args = {
				combatdesc = {
					order = 0,
					name = L["Combat reminder description"],
					type = "description",
				},
				drainsoulreminder = {
					type = "group",
					order = 1,
					name = L["Drain Soul"],
					args = {
						drainsoulsound = {
							type = "toggle",
							name = L["Play sound reminder"],
							desc = L["Play Drain Soul sound reminder"],
							order = 10,
							get = "GetPlayDrainSoul",
							set = "SetPlayDrainSoul",
						},
						drainsoulmessage = {
							type = "toggle",
							name = L["Message reminder"],
							desc = L["Show Drain Soul message reminder"],
							order = 20,
							get = "GetShowDrainSoulMessage",
							set = "SetShowDrainSoulMessage",
						},
						drainsoulframe = {
							type = "toggle",
							name = L["Show Drain Soul Frame"],
							desc = L["Drain Soul will be shown in the WarlockReminder Frame"],
							order = 30,
							get = "GetShowDrainSoulFrame",
							set = "SetShowDrainSoulFrame",
							width = "full",
						},
						drainsoulpercent = {
							type = "range",
							name = L["Show reminder at"],
							desc = L["Show Drain Soul reminder at"],
							order = 40,
							min = 0.0,
							max = 1.0,
							step = 0.01,
							isPercent = true,
							get = "GetDrainSoulPercent",
							set = "SetDrainSoulPercent",
						},
						drainsoulhealth = {
							type = "input",
							name = L["Minimum health"],
							desc = L["Minimum health to show the Drain Soul reminder"],
							order = 50,
							get = "GetDrainSoulHealth",
							set = "SetDrainSoulHealth",
						},
						drainsoulduration = {
							type = "range",
							name = L["Duration of Drain Soul Frame"],
							desc = L["How long the Drain Soul Frame will be shown"],
							order = 60,
							disabled = function(self) return not WarlockReminder:GetShowDrainSoulFrame("DrainSoulDuration") end,
							min = 0,
							max = 60,
							step = 1,
							isPercent = false,
							get = "GetDrainSoulDuration",
							set = "SetDrainSoulDuration",
						},
					},
				}, -- END Drainsoul
				decimationreminder = {
					type = "group",
					order = 2,
					name = L["Decimation"],
					args = {
						decimationsound = {
							type = "toggle",
							name = L["Play sound reminder"],
							desc = L["Play Decimation sound reminder"],
							order = 1,
							get = "GetPlayDecimationSound",
							set = "SetPlayDecimationSound",
						},
						decimationmessage = {
							type = "toggle",
							name = L["Message reminder"],
							desc = L["Show Decimation message reminder"],
							order = 2,
							get = "GetShowDecimationMessage",
							set = "SetShowDecimationMessage",
						},
						decimationframe = {
							type = "toggle",
							name = L["Show Decimation Frame"],
							desc = L["Show Decimation Frame"],
							order = 3,
							get = "GetShowDecimationFrame",
							set = "SetShowDecimationFrame",
						},
					},
				}, -- END Decimation
				moltencorereminder = {
					type = "group",
					order = 3,
					name = L["Molten Core"],
					args = {
						moltencoresound = {
							type = "toggle",
							name = L["Play sound reminder"],
							desc = L["Play Molten Core sound reminder"],
							order = 1,
							get = "GetPlayMoltenCoreSound",
							set = "SetPlayMoltenCoreSound",
						},
						moltencoremessage = {
							type = "toggle",
							name = L["Message reminder"],
							desc = L["Show Molten Core message reminder"],
							order = 2,
							get = "GetShowMoltenCoreMessage",
							set = "SetShowMoltenCoreMessage",
						},
						moltencoreframe = {
							type = "toggle",
							name = L["Show Molten Core Frame"],
							desc = L["Show Molten Core Frame"],
							order = 3,
							get = "GetShowMoltenCoreFrame",
							set = "SetShowMoltenCoreFrame",
						},
					},
				}, -- END Molten Core
				shadowtrancereminder = {
					type = "group",
					order = 4,
					name = L["Shadow Trance"],
					args = {
						shadowtrancesound = {
							type = "toggle",
							name = L["Play sound reminder"],
							desc = L["Play Shadow Trance sound reminder"],
							order = 1,
							get = "GetPlayShadowTranceSound",
							set = "SetPlayShadowTranceSound",
						},
						shadowtrancemessage = {
							type = "toggle",
							name = L["Message reminder"],
							desc = L["Show Shadow Trance message reminder"],
							order = 2,
							get = "GetShowShadowTranceMessage",
							set = "SetShowShadowTranceMessage",
						},
						shadowtranceframe = {
							type = "toggle",
							name = L["Show Shadow Trance Frame"],
							desc = L["Show Shadow Trance Frame"],
							order = 3,
							get = "GetShowShadowTranceFrame",
							set = "SetShowShadowTranceFrame",
						},
					},
				}, -- END Shadow Trance
				empoweredimpreminder = {
					type = "group",
					order = 5,
					name = L["Empowered Imp"],
					args = {
						empoweredimpsound = {
							type = "toggle",
							name = L["Play sound reminder"],
							desc = L["Play Empowered Imp sound reminder"],
							order = 1,
							get = "GetPlayEmpoweredImpSound",
							set = "SetPlayEmpoweredImpSound",
						},
						empoweredimpmessage = {
							type = "toggle",
							name = L["Message reminder"],
							desc = L["Show Empowered Imp message reminder"],
							order = 2,
							get = "GetShowEmpoweredImpMessage",
							set = "SetShowEmpoweredImpMessage",
						},
						empoweredimpframe = {
							type = "toggle",
							name = L["Show Empowered Imp Frame"],
							desc = L["Show Empowered Imp Frame"],
							order = 3,
							get = "GetShowEmpoweredImpFrame",
							set = "SetShowEmpoweredImpFrame",
						},
					},
				},-- END Empowered Imp
			},
		},
		output = {
            type = "group",
			order = 2,
            name = L["Output Frame"],
            args = {
				outputframe = {
					type = "select",
					name = L["Output Frame"],
					desc = L["Reminders will be shown in the selected frame"],
					order = 1,
					values = OutputFrames,
					get = "GetOutputFrame",
					set = "SetOutputFrame",
				},
				anchorheader = {
					type = "header",
					order = 2,
					name = L["WarlockReminder Frame"],
				},
				anchorshow = {
					type = "execute",
					name = L["Show"],
					desc = L["Anchor Show"],
					order = 3,
					func = "ShowAnchor",
				},
				anchorreset = {
					type = "execute",
					name = L["Reset position"],
					desc = L["Anchor Reset"],
					order = 4,
					func = "ResetAnchor",
				},
				framealpha = {
					type = "range",
					name = L["Frame alpha"],
					desc = L["Frame alpha"],
					order = 5,
					min = 0.0,
					softMin = 0.25,
					max = 1.0,
					step = 0.05,
					isPercent = true,
					get = "GetAnchorAlpha",
					set = "SetAnchorAlpha",
				},
				framesize = {
					type = "range",
					name = L["Frame size"],
					desc = L["Frame size"],
					order = 6,
					min = 0.01,
					softMin = 0.25,
					max = 3,
					softMax = 2,
					step = 0.01,
					isPercent = true,
					get = "GetAnchorSize",
					set = "SetAnchorSize",
				},
			},
		}, -- END output
		darkintent = {
            type = "group",
			order = 3,
            name = L["Dark Intent tracker"],
            args = {
				darkintentshow = {
					type = "toggle",
					order = 10,
					name = L["Show tracker"],
					desc = L["Show Dark Intent tracker"],
					get = "GetShowDarkIntent",
					set = "SetShowDarkIntent",
				},
				darkintentreset = {
					type = "execute",
					name = L["Reset position"],
					desc = L["Dark Intent tracker reset"],
					order = 20,
					func = "ResetDiFrame",
				},
				darkintentlock = {
					type = "toggle",
					name = L["Lock frame"],
					desc = L["Lock frame"],
					order = 30,
					get = "GetDarkIntentLock",
					set = "SetDarkIntentLock",
				},
				darkintentrealm = {
					type = "toggle",
					name = L["Show realm"],
					desc = L["Show realm"],
					order = 40,
					get = "GetDarkIntentShowRealm",
					set = "SetDarkIntentShowRealm",
				},
				darkintentalpha = {
					type = "range",
					name = L["Frame alpha"],
					desc = L["Frame alpha"],
					order = 50,
					min = 0.0,
					softMin = 0.25,
					max = 1.0,
					step = 0.05,
					isPercent = true,
					get = "GetDiFrameAlpha",
					set = "SetDiFrameAlpha",
				},
				darkintentbgalpha = {
					type = "range",
					name = L["Background alpha"],
					desc = L["Background alpha"],
					order = 60,
					min = 0.0,
					max = 1.0,
					step = 0.05,
					isPercent = true,
					get = "GetDiBgAlpha",
					set = "SetDiBgAlpha",
				},
				darkintentsize = {
					type = "range",
					name = L["Frame size"],
					desc = L["Frame size"],
					order = 70,
					min = 0.01,
					softMin = 0.5,
					max = 5,
					softMax = 2,
					step = 0.01,
					isPercent = true,
					get = "GetDiFrameSize",
					set = "SetDiFrameSize",
				},
				darkintentextrawidth = {
					type = "range",
					name = L["Extra width"],
					desc = L["Extra width"],
					order = 80,
					min = 0.00,
					max = 1000,
					softMax = 100,
					step = 1,
					get = "GetDiExtraWidth",
					set = "SetDiExtraWidth",
				},
				darkintentfontsize = {
					type = "range",
					name = L["Font size"],
					desc = L["Font size"],
					order = 90,
					min = 0.00,
					softMin = 7,
					max = 32,
					step = 1,
					get = "GetDiFontSize",
					set = "SetDiFontSize",
				},
			},
		}, -- END Dark Intent
		isftimer = {
			type = "group",
			order = 4,
			name = L["Improved Soul Fire timer"],
			args = {
				isftoggle = {
					type = "toggle",
					order = 10,
					name = L["Show Improved Soul Fire timer"],
					desc = L["Show Improved Soul Fire timer"],
					get = "GetShowIsf",
					set = "SetShowIsf",
				},
				isfshow = {
					type = "execute",
					name = L["Show"],
					desc = L["Show Improved Soul Fire timer"],
					order = 20,
					func = "ShowIsfBar",
				},
				isflock = {
					type = "toggle",
					name = L["Lock frame"],
					desc = L["Lock frame"],
					order = 30,
					get = "GetIsfLock",
					set = "SetIsfLock",
				},
				isfreset = {
					type = "execute",
					name = L["Reset position"],
					desc = L["Improved Soul Fire reset"],
					order = 40,
					func = "ResetIsfBar",
				},
				isfcombat = {
					type = "toggle",
					name = L["Show only in combat"],
					desc = L["Show only in combat"],
					order = 50,
					get = "GetIsfCombat",
					set = "SetIsfCombat",
				},
				isftextorientation = {
					type = "select",
					name = L["Text orientation"],
					desc = L["Text orientation"],
					order = 60,
					values = TextPositions,
					get = "GetIsfTextPosition",
					set = "SetIsfTextPosition",
				},
				isffontsize = {
					type = "range",
					name = L["Font size"],
					desc = L["Font size"],
					order = 70,
					min = 0.00,
					softMin = 7,
					max = 32,
					step = 1,
					get = "GetIsfFontSize",
					set = "SetIsfFontSize",
				},
				isfalpha = {
					type = "range",
					name = L["Frame alpha"],
					desc = L["Frame alpha"],
					order = 80,
					min = 0.0,
					softMin = 0.25,
					max = 1.0,
					step = 0.05,
					isPercent = true,
					get = "GetIsfAlpha",
					set = "SetIsfAlpha",
				},
				isfwidth = {
					type = "range",
					name = L["Width"],
					desc = L["Width"],
					order = 90,
					min = 0.00,
					max = 1000,
					softMax = 400,
					step = 1,
					get = "GetIsfWidth",
					set = "SetIsfWidth",
				},
				isfheight = {
					type = "range",
					name = L["Height"],
					desc = L["Height"],
					order = 100,
					min = 0.00,
					max = 100,
					softMax = 50,
					step = 1,
					get = "GetIsfHeight",
					set = "SetIsfHeight",
				},
			},
		}, -- END Isf
		-- CustomReminder
		customreminder = {
			type = "group",
			order = 5,
			name = L["Custom Reminder"],
			args = {
				customanchorheader = {
					type = "header",
					order = 10,
					name = L["Custom Reminder"],
				},
				customshow = {
					type = "toggle",
					order = 20,
					name = L["Show Custom Reminder"],
					desc = L["Show Custom Reminder"],
					get = "GetShowCustom",
					set = "SetShowCustom",
				},
				customanchorshow = {
					type = "execute",
					name = L["Show"],
					desc = L["Anchor Show"],
					order = 30,
					func = "ShowCustomAnchor",
				},
				customsound = {
					type = "toggle",
					order = 40,
					name = L["Play sound reminder"],
					desc = L["Play sound reminder"],
					get = "GetSoundCustom",
					set = "SetSoundCustom",
				},
				
				customanchorreset = {
					type = "execute",
					name = L["Reset position"],
					desc = L["Anchor Reset"],
					order = 50,
					func = "ResetCustomAnchor",
				},
				customframealpha = {
					type = "range",
					name = L["Frame alpha"],
					desc = L["Frame alpha"],
					order = 60,
					min = 0.0,
					softMin = 0.25,
					max = 1.0,
					step = 0.05,
					isPercent = true,
					get = "GetCustomAnchorAlpha",
					set = "SetCustomAnchorAlpha",
				},
				customframesize = {
					type = "range",
					name = L["Frame size"],
					desc = L["Frame size"],
					order = 70,
					min = 0.01,
					softMin = 0.25,
					max = 3,
					softMax = 2,
					step = 0.01,
					isPercent = true,
					get = "GetCustomAnchorSize",
					set = "SetCustomAnchorSize",
				},
				customremindersetup = {
					type = "group",
					order = 1,
					name = L["Spell setup"],
					args = {
						addspell = {
							name = L["Add a Spell"],
							desc = L["Add a new spell to the list by entering the Spell-Id here."],
							type = "input",
							order = 10,
							get = false,
							set = "AddCustomSpell",
							width = "double",
						},
						selectspell = {
							name = "",
							desc = "",
							type = "multiselect",
							order = 20,
							get = "GetCurrentSpells",
							set = "SetCurrentSpells",
							values = "GetCustomSpells",
							width = "double",
						},
						removespell = {
							name = L["Remove Spell"],
							desc = L["Remove the selected spell from the list."],
							type = "execute",
							func = "RemoveCustomSpell",
							order = 30,
						},
						customdesc = {
							order = 100,
							name = L["Use spell-ids from wowhead.com's Urls, e.g. Devious Minds: http://www.wowhead.com/spell=70840 => Spell-Id: 70840"],
							type = "description",
						},
					},
				},
			},
		}, -- END CustomReminder
    },
}
-- END Options

-- If "wlrframe" is selected returns false, otherwise true
function WarlockReminder:ShowAnchorOptions()
	if self:GetOutputFrame() == "wlrframe" then return false
	else return true end
end

-- Show the anchor
function WarlockReminder:ShowAnchor()
	wlranchor:Show()
	self:WlrFrame(true, FelArmor)
end

-- Show the customanchor
function WarlockReminder:ShowCustomAnchor()
	wlrcustomanchor:Show()
	self:WlrCustomFrame(true, FelSpark)
end

-- Show the diFrame
function WarlockReminder:ShowDiFrame()
	diFrame:Show()
end

-- Show the isfBar
function WarlockReminder:ShowIsfBar()
	isfBar:Show()
end

-- New Profile
function WarlockReminder:NewConfig(db, profile)
	self:ResetAnchor()
	self:ResetCustomAnchor()
	self:ResetDiFrame()
end

-- Profile changes
function WarlockReminder:RefreshConfig(db, newProfile)
	-- Set the anchor position
	wlranchor:ClearAllPoints()
	wlranchor:SetPoint("TOPLEFT",UIParent,"BOTTOMLEFT", self.db.profile.wlrAnchorLeft, self.db.profile.wlrAnchorTop)
	self:FramesToAnchor()
	wlrframe:SetAlpha(self.db.profile.wlrAnchorAlpha)
	wlrframe:SetWidth(48*self.db.profile.wlrAnchorSize)
	wlrframe:SetHeight(48*self.db.profile.wlrAnchorSize)
	
	-- Set the positions
	self:CustomSetup()
	self:DiFrameSetup()
	self:IsfSetup()
end

-- Setup options
function WarlockReminder:SetUpOptions()
	local wlrprofile = LibStub('AceDBOptions-3.0'):GetOptionsTable(self.db)
	-- Add dual-spec support
	local LibDualSpec = LibStub("LibDualSpec-1.0", true)
	if LibDualSpec then
		LibDualSpec:EnhanceDatabase(self.db, "WarlockReminder")
		LibDualSpec:EnhanceOptions(wlrprofile, self.db)
	end
	
	local config = LibStub("AceConfig-3.0");
	config:RegisterOptionsTable("WarlockReminder", SlashOptions, SlashCmds);
	
	local registry = LibStub("AceConfigRegistry-3.0");
	-- Add option windows
    registry:RegisterOptionsTable("WarlockReminder Main", wlroptions)
	registry:RegisterOptionsTable("WarlockReminder Profiles", wlrprofile)
	
	local dialog = LibStub("AceConfigDialog-3.0");
	self.optionFrames = {
		main = dialog:AddToBlizOptions("WarlockReminder Main", "WarlockReminder"),
		profile = dialog:AddToBlizOptions("WarlockReminder Profiles", L["Profiles"], "WarlockReminder"),
	}
end
-- END Setup options


-- returns enabled or disabled for output
function WarlockReminder:GetOptionStatus(status)
	if status then
		return L["Enabled"]
	else
		return L["Disabled"]
	end
end

-- Armor
function WarlockReminder:GetShowArmor(info)
    return self.db.profile.showArmor
end

function WarlockReminder:SetShowArmor(info, newValue)
    self.db.profile.showArmor = newValue
	self:Print(L["Show armor reminder"] .. " " .. self:GetOptionStatus(self:GetShowArmor()))
	self:Reminder()
end

-- Soul Link
function WarlockReminder:GetShowSL(info)
    return self.db.profile.showSL
end

function WarlockReminder:SetShowSL(info, newValue)
    self.db.profile.showSL = newValue
	self:Print(L["Show Soul Link reminder"] .. " " .. self:GetOptionStatus(self:GetShowSL()))
	self:Reminder()
end

-- Flask
function WarlockReminder:GetShowFlask(info)
    return self.db.profile.showFlask
end

function WarlockReminder:SetShowFlask(info, newValue)
    self.db.profile.showFlask = newValue
	self:Print(L["Show Flask and Elixir reminder"] .. " " .. self:GetOptionStatus(self:GetShowFlask()))
	self:Reminder()
end

-- Pet
function WarlockReminder:GetShowPet(info)
    return self.db.profile.showPet
end

function WarlockReminder:SetShowPet(info, newValue)
    self.db.profile.showPet = newValue
	self:Print(L["Show pet reminder"] .. " " .. self:GetOptionStatus(self:GetShowPet()))
	self:Reminder()
end

function WarlockReminder:GetPetAffliction(info)
    return self.db.profile.petAffliction
end

function WarlockReminder:SetPetAffliction(info, newValue)
    self.db.profile.petAffliction = newValue
	self:Print(L["Pet for Affliction"] .. ": " .. PetChoice[self:GetPetAffliction()])
end

function WarlockReminder:GetPetDemonology(info)
    return self.db.profile.petDemonology
end

function WarlockReminder:SetPetDemonology(info, newValue)
    self.db.profile.petDemonology = newValue
	self:Print(L["Pet for Demonology"] .. ": " .. PetChoice[self:GetPetDemonology()])
end

function WarlockReminder:GetPetDestruction(info)
    return self.db.profile.petDestruction
end

function WarlockReminder:SetPetDestruction(info, newValue)
    self.db.profile.petDestruction = newValue
	self:Print(L["Pet for Destruction"] .. ": " .. PetChoice[self:GetPetDestruction()])
end

-- Food
function WarlockReminder:GetShowFood(info)
    return self.db.profile.showFood
end

function WarlockReminder:SetShowFood(info, newValue)
    self.db.profile.showFood = newValue
	self:Print(L["Show food reminder"] .. " " .. self:GetOptionStatus(self:GetShowFood()))
	self:Reminder()
end

-- Output Frame
function WarlockReminder:GetOutputFrame(info)
    return self.db.profile.outputFrame
end

function WarlockReminder:SetOutputFrame(info, newValue)
    self.db.profile.outputFrame = newValue
	self:Print(L["Output Frame"] .. ": " .. OutputFrames[self:GetOutputFrame()])
	self:DrainSoulReminder()
end

-- WlrFrame Position
function WarlockReminder:GetWlrAnchorTop(info)
    return self.db.profile.wlrAnchorTop
end

function WarlockReminder:SetWlrAnchorTop(info, newValue)
    self.db.profile.wlrAnchorTop = newValue
end

function WarlockReminder:GetWlrAnchorLeft(info)
    return self.db.profile.wlrAnchorLeft
end

function WarlockReminder:SetWlrAnchorLeft(info, newValue)
    self.db.profile.wlrAnchorLeft = newValue
end
-- END WlrFrame

-- WlrFrame Config
function WarlockReminder:GetAnchorAlpha(info)
    return self.db.profile.wlrAnchorAlpha
end

function WarlockReminder:SetAnchorAlpha(info, newValue)
	wlrframe:SetAlpha(newValue)
    self.db.profile.wlrAnchorAlpha = newValue
end

function WarlockReminder:GetAnchorSize(info)
    return self.db.profile.wlrAnchorSize
end

function WarlockReminder:SetAnchorSize(info, newValue)
	wlrframe:SetWidth(48*newValue)
	wlrframe:SetHeight(48*newValue)
    self.db.profile.wlrAnchorSize = newValue
end
-- END WlrFrame Config

-- Drain Soul
-- Play ds sound
function WarlockReminder:GetPlayDrainSoul(info)
    return self.db.profile.playDrainSoul
end

function WarlockReminder:SetPlayDrainSoul(info, newValue)
    self.db.profile.playDrainSoul = newValue
	self:Print(L["Play Drain Soul sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayDrainSoul()))
	self:DrainSoulReminder()
end

-- Show ds message
function WarlockReminder:GetShowDrainSoulMessage(info)
    return self.db.profile.showDrainSoulMessage
end

function WarlockReminder:SetShowDrainSoulMessage(info, newValue)
    self.db.profile.showDrainSoulMessage = newValue
	self:Print(L["Show Drain Soul message reminder"] .. " " .. self:GetOptionStatus(self:GetShowDrainSoulMessage()))
	self:DrainSoulReminder()
end

-- Show ds reminder at x%
function WarlockReminder:GetDrainSoulPercent(info)
    return self.db.profile.drainSoulPercent
end

function WarlockReminder:SetDrainSoulPercent(info, newValue)
    self.db.profile.drainSoulPercent = newValue
end

-- Minimum Health
function WarlockReminder:GetDrainSoulHealth(info)
    return self.db.profile.drainSoulHealth
end

function WarlockReminder:SetDrainSoulHealth(info, newValue)
    self.db.profile.drainSoulHealth = newValue
	self:Print(L["Minimum health"] .. ": " .. self:GetDrainSoulHealth())
	self:DrainSoulReminder()
end

-- Drain Soul Frame Show
function WarlockReminder:GetShowDrainSoulFrame(info)
    return self.db.profile.showDrainSoulFrame
end

function WarlockReminder:SetShowDrainSoulFrame(info, newValue)
    self.db.profile.showDrainSoulFrame = newValue
	self:Print(L["Show Drain Soul Frame"] .. " " .. self:GetOptionStatus(self:GetShowDrainSoulFrame()))
	self:DrainSoulReminder()
end

-- Drain Soul Frame Duration
function WarlockReminder:GetDrainSoulDuration(info)
    return self.db.profile.drainSoulDuration
end

function WarlockReminder:SetDrainSoulDuration(info, newValue)
    self.db.profile.drainSoulDuration = newValue
	self:DrainSoulReminder()
end
-- END Drain Soul

-- Decimation
-- Decimation play sound
function WarlockReminder:GetPlayDecimationSound(info)
    return self.db.profile.playDecimationSound
end

function WarlockReminder:SetPlayDecimationSound(info, newValue)
    self.db.profile.playDecimationSound = newValue
	self:Print(L["Play Decimation sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayDecimationSound()))
end

-- Decimation Message Show
function WarlockReminder:GetShowDecimationMessage(info)
    return self.db.profile.showDecimationMessage
end

function WarlockReminder:SetShowDecimationMessage(info, newValue)
    self.db.profile.showDecimationMessage = newValue
	self:Print(L["Show Decimation message reminder"] .. " " .. self:GetOptionStatus(self:GetShowDecimationMessage()))
end

-- Decimation Frame Show
function WarlockReminder:GetShowDecimationFrame(info)
    return self.db.profile.showDecimationFrame
end

function WarlockReminder:SetShowDecimationFrame(info, newValue)
    self.db.profile.showDecimationFrame = newValue
	self:Print(L["Show Decimation Frame"] .. " " .. self:GetOptionStatus(self:GetShowDecimationFrame()))
end
-- END Decimation

-- Molten Core
-- Molten Core play sound
function WarlockReminder:GetPlayMoltenCoreSound(info)
    return self.db.profile.playMoltenCoreSound
end

function WarlockReminder:SetPlayMoltenCoreSound(info, newValue)
    self.db.profile.playMoltenCoreSound = newValue
	self:Print(L["Play Molten Core sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayMoltenCoreSound()))
end

-- Molten Core Message Show
function WarlockReminder:GetShowMoltenCoreMessage(info)
    return self.db.profile.showMoltenCoreMessage
end

function WarlockReminder:SetShowMoltenCoreMessage(info, newValue)
    self.db.profile.showMoltenCoreMessage = newValue
	self:Print(L["Show Molten Core message reminder"] .. " " .. self:GetOptionStatus(self:GetShowMoltenCoreMessage()))
end

-- Molten Core Frame Show
function WarlockReminder:GetShowMoltenCoreFrame(info)
    return self.db.profile.showMoltenCoreFrame
end

function WarlockReminder:SetShowMoltenCoreFrame(info, newValue)
    self.db.profile.showMoltenCoreFrame = newValue
	self:Print(L["Show Molten Core Frame"] .. " " .. self:GetOptionStatus(self:GetShowMoltenCoreFrame()))
end
-- END Molten Core

-- Shadow Trance
-- Shadow Trance play sound
function WarlockReminder:GetPlayShadowTranceSound(info)
    return self.db.profile.playShadowTranceSound
end

function WarlockReminder:SetPlayShadowTranceSound(info, newValue)
    self.db.profile.playShadowTranceSound = newValue
	self:Print(L["Play Shadow Trance sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayShadowTranceSound()))
end

-- Shadow Trance Message Show
function WarlockReminder:GetShowShadowTranceMessage(info)
    return self.db.profile.showShadowTranceMessage
end

function WarlockReminder:SetShowShadowTranceMessage(info, newValue)
    self.db.profile.showShadowTranceMessage = newValue
	self:Print(L["Show Shadow Trance message reminder"] .. " " .. self:GetOptionStatus(self:GetShowShadowTranceMessage()))
end

-- Shadow Trance Frame Show
function WarlockReminder:GetShowShadowTranceFrame(info)
    return self.db.profile.showShadowTranceFrame
end

function WarlockReminder:SetShowShadowTranceFrame(info, newValue)
    self.db.profile.showShadowTranceFrame = newValue
	self:Print(L["Show Shadow Trance Frame"] .. " " .. self:GetOptionStatus(self:GetShowShadowTranceFrame()))
end
-- END Shadow Trance

-- Empowered Imp
-- Empowered Imp play sound
function WarlockReminder:GetPlayEmpoweredImpSound(info)
    return self.db.profile.playEmpoweredImpSound
end

function WarlockReminder:SetPlayEmpoweredImpSound(info, newValue)
    self.db.profile.playEmpoweredImpSound = newValue
	self:Print(L["Play Empowered Imp sound reminder"] .. " " .. self:GetOptionStatus(self:GetPlayEmpoweredImpSound()))
end

-- Empowered Imp Message Show
function WarlockReminder:GetShowEmpoweredImpMessage(info)
    return self.db.profile.showEmpoweredImpMessage
end

function WarlockReminder:SetShowEmpoweredImpMessage(info, newValue)
    self.db.profile.showEmpoweredImpMessage = newValue
	self:Print(L["Show Empowered Imp message reminder"] .. " " .. self:GetOptionStatus(self:GetShowEmpoweredImpMessage()))
end

-- Empowered Imp Frame Show
function WarlockReminder:GetShowEmpoweredImpFrame(info)
    return self.db.profile.showEmpoweredImpFrame
end

function WarlockReminder:SetShowEmpoweredImpFrame(info, newValue)
    self.db.profile.showEmpoweredImpFrame = newValue
	self:Print(L["Show Empowered Imp Frame"] .. " " .. self:GetOptionStatus(self:GetShowEmpoweredImpFrame()))
end
-- END Empowered Imp

-- Dark Intent
function WarlockReminder:GetShowDarkIntent(info)
    return self.db.profile.showDarkIntentFrame
end

function WarlockReminder:SetShowDarkIntent(info, newValue)
    self.db.profile.showDarkIntentFrame = newValue
	self:Print(L["Show Dark Intent tracker"] .. " " .. self:GetOptionStatus(self:GetShowDarkIntent()))
	self:DiFrameSetup()
end

-- diFrame Position
function WarlockReminder:GetDiFrameTop(info)
    return self.db.profile.diFrameTop
end

function WarlockReminder:SetDiFrameTop(info, newValue)
    self.db.profile.diFrameTop = newValue
end

function WarlockReminder:GetDiFrameLeft(info)
    return self.db.profile.diFrameLeft
end

function WarlockReminder:SetDiFrameLeft(info, newValue)
    self.db.profile.diFrameLeft = newValue
end

-- diFrame Config
function WarlockReminder:GetDiFrameAlpha(info)
    return self.db.profile.diFrameAlpha
end

function WarlockReminder:SetDiFrameAlpha(info, newValue)
    self.db.profile.diFrameAlpha = newValue
	self:DiFrameSetup()
end

function WarlockReminder:GetDiBgAlpha(info)
    return self.db.profile.diBgAlpha
end

function WarlockReminder:SetDiBgAlpha(info, newValue)
    self.db.profile.diBgAlpha = newValue
	self:DiFrameSetup()
end

function WarlockReminder:GetDiFrameSize(info)
    return self.db.profile.diFrameSize
end

function WarlockReminder:SetDiFrameSize(info, newValue)
    self.db.profile.diFrameSize = newValue
	self:DiFrameSetup()
end

function WarlockReminder:GetDiExtraWidth(info)
    return self.db.profile.diExtraWidth
end

function WarlockReminder:SetDiExtraWidth(info, newValue)
    self.db.profile.diExtraWidth = newValue
	self:DiFrameSetup()
end

function WarlockReminder:GetDarkIntentLock(info)
    return self.db.profile.diFrameLock
end

function WarlockReminder:SetDarkIntentLock(info, newValue)
    self.db.profile.diFrameLock = newValue
	if(newValue == true) then 
		diFrame:SetMovable(0)
	else 
		diFrame:SetMovable(1) 
	end
end

function WarlockReminder:GetDarkIntentShowRealm(info)
    return self.db.profile.diFrameShowRealm
end

function WarlockReminder:SetDarkIntentShowRealm(info, newValue)
    self.db.profile.diFrameShowRealm = newValue
end

function WarlockReminder:GetDiFontSize(info)
    return self.db.profile.diFontSize
end

function WarlockReminder:SetDiFontSize(info, newValue)
    self.db.profile.diFontSize = newValue
	self:DiFrameSetup()
end
-- End Dark Intent

-- Isf
-- Position
function WarlockReminder:GetIsfTop(info)
    return self.db.profile.isfTop
end

function WarlockReminder:SetIsfTop(info, newValue)
    self.db.profile.isfTop = newValue
end

function WarlockReminder:GetIsfLeft(info)
    return self.db.profile.isfLeft
end

function WarlockReminder:SetIsfLeft(info, newValue)
    self.db.profile.isfLeft = newValue
end

-- Text
function WarlockReminder:GetIsfTextPosition(info)
    return self.db.profile.isfTextPosition
end

function WarlockReminder:SetIsfTextPosition(info, newValue)
    self.db.profile.isfTextPosition = newValue
	self:IsfSetup()
end

function WarlockReminder:GetIsfFontSize(info)
    return self.db.profile.isfFontSize
end

function WarlockReminder:SetIsfFontSize(info, newValue)
    self.db.profile.isfFontSize = newValue
	self:IsfSetup()
end

-- Show
function WarlockReminder:GetShowIsf(info)
    return self.db.profile.showIsf
end

function WarlockReminder:SetShowIsf(info, newValue)
    self.db.profile.showIsf = newValue
	self:Print(L["Show Improved Soul Fire timer"] .. " " .. self:GetOptionStatus(self:GetShowIsf()))
	self:IsfSetup()
end

-- Lock
function WarlockReminder:GetIsfLock(info)
    return self.db.profile.isfLock
end

function WarlockReminder:SetIsfLock(info, newValue)
    self.db.profile.isfLock = newValue
	if(newValue == true) then 
		isfBar:SetMovable(0)
	else 
		isfBar:SetMovable(1) 
	end
end

-- Alpha
function WarlockReminder:GetIsfAlpha(info)
    return self.db.profile.isfAlpha
end

function WarlockReminder:SetIsfAlpha(info, newValue)
    self.db.profile.isfAlpha = newValue
	self:IsfSetup()
end

-- Width
function WarlockReminder:GetIsfWidth(info)
    return self.db.profile.isfWidth
end

function WarlockReminder:SetIsfWidth(info, newValue)
    self.db.profile.isfWidth = newValue
	self:IsfSetup()
end

-- Height
function WarlockReminder:GetIsfHeight(info)
    return self.db.profile.isfHeight
end

function WarlockReminder:SetIsfHeight(info, newValue)
    self.db.profile.isfHeight = newValue
	self:IsfSetup()
end

-- Combat
function WarlockReminder:GetIsfCombat(info)
    return self.db.profile.isfInCombat
end

function WarlockReminder:SetIsfCombat(info, newValue)
    self.db.profile.isfInCombat = newValue
end
-- End Isf


-- CustomReminder

--Show
function WarlockReminder:GetShowCustom(info)
	return self.db.profile.showCustom
end

function WarlockReminder:SetShowCustom(info, newValue)
	self.db.profile.showCustom = newValue
	self:Print(L["Show Custom Reminder"] .. " " .. self:GetOptionStatus(self:GetShowCustom()))
	self:CustomSetup()
end

-- Sound
function WarlockReminder:GetSoundCustom(info)
	return self.db.profile.soundCustom
end

function WarlockReminder:SetSoundCustom(info, newValue)
	self.db.profile.soundCustom = newValue
	self:Print(L["Play sound reminder"] .. " " .. self:GetOptionStatus(self:GetSoundCustom()))
end


-- WlrCustomFrame Position
function WarlockReminder:GetWlrCustomAnchorTop(info)
    return self.db.profile.wlrCustomAnchorTop
end

function WarlockReminder:SetWlrCustomAnchorTop(info, newValue)
    self.db.profile.wlrCustomAnchorTop = newValue
end

function WarlockReminder:GetWlrCustomAnchorLeft(info)
    return self.db.profile.wlrCustomAnchorLeft
end

function WarlockReminder:SetWlrCustomAnchorLeft(info, newValue)
    self.db.profile.wlrCustomAnchorLeft = newValue
end
-- END WlrCustomFrame Position

-- WlrCustomFrame Properties
function WarlockReminder:GetCustomAnchorAlpha(info)
    return self.db.profile.wlrCustomAnchorAlpha
end

function WarlockReminder:SetCustomAnchorAlpha(info, newValue)
	wlrcustomframe:SetAlpha(newValue)
    self.db.profile.wlrCustomAnchorAlpha = newValue
end

function WarlockReminder:GetCustomAnchorSize(info)
    return self.db.profile.wlrCustomAnchorSize
end

function WarlockReminder:SetCustomAnchorSize(info, newValue)
	wlrcustomframe:SetWidth(48*newValue)
	wlrcustomframe:SetHeight(48*newValue)
    self.db.profile.wlrCustomAnchorSize = newValue
end
-- END WlrCustomFrame Position

-- End CustomRemidner
